@@ -1,5 +1,7 @@
 class NeatoException(Exception):
-    pass
+    """
+    General neato exception.
+    """
 
 
 class NeatoLoginException(NeatoException):
@@ -7,20 +9,14 @@ class NeatoLoginException(NeatoException):
     To indicate there is a login issue.
     """
 
-    pass
-
 
 class NeatoRobotException(NeatoException):
     """
     To be thrown anytime there is a robot error.
     """
 
-    pass
-
 
 class NeatoUnsupportedDevice(NeatoRobotException):
     """
     To be thrown only for unsupported devices.
     """
-
-    pass
