@@ -22,6 +22,6 @@ class Neato(Vendor):
     name = "neato"
     endpoint = "https://beehive.neatocloud.com/"
     auth_endpoint = "https://apps.neatorobotics.com/oauth2/authorize"
-    token_endpoint = "https://beehive.neatocloud.com/oauth2/token"
+    token_endpoint = "https://beehive.neatocloud.com/oauth2/token"  # nosec
     scope = ["public_profile", "control_robots", "maps"]
-    cert_path = os.path.join(os.path.dirname(__file__), "cert", "neatocloud.com.crt")
+    cert_path = None
